@@ -9,10 +9,6 @@ extern SEXP _optmatch_mahalanobisHelper(SEXP, SEXP, SEXP);
 extern SEXP _optmatch_r_smahal(SEXP, SEXP, SEXP);
 extern SEXP _optmatch_subsetInfSparseMatrix(SEXP, SEXP, SEXP);
 
-/* .Fortran calls */
-extern void F77_NAME(relaxalg)(void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *);
-extern void F77_NAME(relaxalgold)(void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *);
-
 static const R_CallMethodDef CallEntries[] = {
   {"_optmatch_ismOps",                (DL_FUNC) &_optmatch_ismOps,                3},
   {"_optmatch_mahalanobisHelper",     (DL_FUNC) &_optmatch_mahalanobisHelper,     3},
@@ -21,14 +17,8 @@ static const R_CallMethodDef CallEntries[] = {
   {NULL, NULL, 0}
 };
 
-static const R_FortranMethodDef FortranEntries[] = {
-  {"relaxalg",    (DL_FUNC) &F77_NAME(relaxalg),    11},
-  {"relaxalgold", (DL_FUNC) &F77_NAME(relaxalgold), 11},
-  {NULL, NULL, 0}
-};
-
 void R_init_optmatch(DllInfo *dll)
 {
-  R_registerRoutines(dll, NULL, CallEntries, FortranEntries, NULL);
+  R_registerRoutines(dll, NULL, CallEntries, NULL, NULL);
   R_useDynamicSymbols(dll, FALSE);
 }
