@@ -9,14 +9,14 @@ SEXP r_smahal(SEXP index, SEXP data, SEXP z) {
   Rcpp::NumericMatrix dataMat(data);
   DMAT * ans = smahal(dataMat.nrow(), dataMat.ncol(), REAL(data), LOGICAL(z));
   if(ans == NULL || ans->nr < 1 || ans->nc <1)
-    error("smahal_nosexp returned an invalid answer");
+    Rf_error("smahal_nosexp returned an invalid answer");
 
   SEXP out;
   Rf_protect(out = Rf_allocMatrix(REALSXP, ans->nr, ans->nc));
   memcpy(REAL(out), ans->data, ans->nr * ans->nc * sizeof(double));
 
-  Free(ans->data);
-  Free(ans);
+  R_Free(ans->data);
+  R_Free(ans);
   Rf_unprotect(1);
 
   return out;
