@@ -1,8 +1,8 @@
 context("CBPS integration")
 
 test_that("internal predict.CBPS function", {
-  if (require('CBPS')) {
-    cpsm <- CBPS(pr ~ date + t1 + t2 + cap + ne + ct + bw + cum.n, ATT = 0, data = nuclearplants)
+  if (requireNamespace('CBPS', quietly = TRUE)) {
+    cpsm <- CBPS::CBPS(pr ~ date + t1 + t2 + cap + ne + ct + bw + cum.n, ATT = 0, data = nuclearplants)
     expect_true(is(fullmatch(cpsm, data = nuclearplants), "optmatch"))
 
     # Check recognition of type argument.
